@@ -17,6 +17,7 @@ class SourceVirusshare(Source):
 
     NAME = "virusshare"
     URL_API = "https://virusshare.com/apiv2"
+    SUPPORTED_HASHES = ("md5", "sha1", "sha256", "sha512")
 
     def download_file(self, sample_hash: str, output_path: Path) -> bool:
         """
@@ -34,8 +35,12 @@ class SourceVirusshare(Source):
                 logger.warning("Rate limited")
             return False
 
-        data = self._decrypt_zip(response.content)
-        with output_path.open("wb") as h_file:
-            h_file.write(data)
-
-        return True
+        try:
+            data = self._decrypt_zip(response.content)
+            with output_path.open("wb") as h_file:
+                h_file.write(data)
+        except ValueError as e:
+            logger.warning(f"Failed to decrypt ZIP file: {e}")
+            return False
+        else:
+            return True
